/**
* Copyright (c) 2002-2009 Nokia Corporation and/or its subsidiary(-ies).
* All rights reserved.
* This component and the accompanying materials are made available
* under the terms of "Eclipse Public License v1.0"
* which accompanies this distribution, and is available
* at the URL "http://www.eclipse.org/legal/epl-v10.html".
*
* Initial Contributors:
* Nokia Corporation - initial contribution.
*
* Contributors:
*
* Description:
*
*/



/**
 @file ListsStep.h
 @internalTechnology
*/
#if (!defined __LISTS_STEP_H__)
#define __LISTS_STEP_H__
#include <TestExecuteStepBase.h>
#include "tcoredumpserversuitestepbase.h"
#include "tcoredumpcommon.h"

class CListsStep : public CTe_coredumpserverSuiteStepBase
	{
public:
	CListsStep();
	~CListsStep();
	
	void ClientAppL();
	
	virtual TVerdict doTestStepPreambleL();
	virtual TVerdict doTestStepL();
	virtual TVerdict doTestStepPostambleL();

// Please add/modify your class members here:
private:

	RCoreDumpSession iSess;

	void ListProcessesL();
	void ListThreadsL();
	void ListExecutables();
	void ListPlugins();
	
	};

_LIT(KListsStep,"ListsStep");

#endif
